@@ -6,10 +6,10 @@ module GettextI18nRails
       File.extname(file) == ".#{extension}"
     end
 
-    def self.parse(file, msgids = [])
+    def self.parse(file, _options = {}, msgids = [])
       return msgids unless load_library
       code = convert_to_code(File.read(file))
-      RubyGettextExtractor.parse_string(code, file, msgids)
+      RubyGettextExtractor.parse_string(code, msgids, file)
     rescue Racc::ParseError => e
       $stderr.puts "file ignored: ruby_parser cannot read #{extension} files with 1.9 syntax --- #{file}: (#{e.message.strip})"
       return msgids
